/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package org.biolegato.gdesupport.canvas.listeners;

import org.biolegato.gdesupport.canvas.textarea.BLTextArea;

/**
 * Used to communicate changes in the canvas cursor position.
 *
 * @author Graham Alvare
 * @author Brian Fristensky
 */
public interface CursorListener {

    /**
     * Communicates a change in cursor position.
     *
     * @param source the source of the cursor change.
     * @param column the new column co-ordinate of the cursor.
     * @param row the new row co-ordinate of the cursor.
     */
    public void cursorChange (BLTextArea source, int column, int row);

}
